postal_address.tests package
============================

Submodules
----------

postal_address.tests.test_address module
----------------------------------------

.. automodule:: postal_address.tests.test_address
    :members:
    :undoc-members:
    :show-inheritance:

postal_address.tests.test_territory module
------------------------------------------

.. automodule:: postal_address.tests.test_territory
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: postal_address.tests
    :members:
    :undoc-members:
    :show-inheritance:
